Coverage report

# Coverage report: 85%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 599 | 91 | 0 | 85%
src/hatch_ci/__init__.py | 2 | 0 | 0 | 100%
src/hatch_ci/cli.py | 72 | 10 | 0 | 86%
src/hatch_ci/common.py | 1 | 1 | 0 | 0%
src/hatch_ci/hooks.py | 5 | 5 | 0 | 0%
src/hatch_ci/scm.py | 172 | 13 | 0 | 92%
src/hatch_ci/script.py | 71 | 10 | 0 | 86%
src/hatch_ci/tools.py | 236 | 12 | 0 | 95%
src/hatch_ci/version_hook.py | 40 | 40 | 0 | 0%

No items found using the specified filter.